@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 """
-    Flask-PluginKit.exceptions
+    flask_pluginkit.exceptions
     ~~~~~~~~~~~~~~~~~~~~~~~~~~
 
     Exception Classes
 
-    :copyright: (c) 2018 by staugur.
-    :license: BSD, see LICENSE for more details.
+    :copyright: (c) 2019 by staugur.
+    :license: BSD 3-Clause, see LICENSE for more details.
 """
 
 
@@ -14,6 +14,18 @@ class PluginError(Exception):
     pass
 
 
+class VersionError(PluginError):
+    pass
+
+
+class PEPError(PluginError):
+    pass
+
+
+class TemplateNotFound(PluginError):
+    pass
+
+
 class TarError(PluginError):
     pass
 
@@ -26,13 +38,5 @@ class InstallError(PluginError):
     pass
 
 
-class CSSLoadError(PluginError):
-    pass
-
-
-class DCPError(PluginError):
-    pass
-
-
-class VersionError(PluginError):
+class NotCallableError(PluginError):
     pass
